%Danny Yagan. December 2009
%Simulation of Optimal Income Distribution given the tax schedule specified
%in tax.m

%% Setup
% elasticity
e = .5;

% taste bounds
a_min = 0;
a_max = 300000;

% the program uses a grid search to approximate each agent's choice of
% optimal income and runs in a loop to avoid exhausting memory in the
% search.  the size of total simulated population = num_iters*num, where 
% num is the size of each iteration's simulated population.  memory
% intensity rises in num.
num_iters = 100;
num = 5000;

% number of points in grid search
grid = 3000;



%% Execution
z = [];
iter = 1;

while (iter<=num_iters)
% wage draws
a_vec = rand(num,1)*(a_max-a_min);

% grid search for optimal income
z_vec = 0:a_max/grid:a_max;
z_mat = z_vec(ones(1,num),:);
c_vec = z_vec-tax(z_vec);
c_mat = c_vec(ones(1,num),:);
a_mat = a_vec(:,ones(1,grid+1));
u_mat = c_mat-a_mat.*((z_mat./a_mat).^(1+1/e))/(1+1/e);
max_u_vec = max(u_mat')';
max_u_mat = max_u_vec(:,ones(1,grid+1));
find_opt_u = (max_u_mat==u_mat);
opt_z_mat = find_opt_u.*z_mat;

% storage of optimal income and iteration
z = [z; max(opt_z_mat')'];
iter = iter+1;
end



%% Kernel density in stata
% load the z vector into stata and execute the command:
% kdensity z if z<=200000, bw(1000) n(1000)
