% September 2011 Gregory Bruich
% Draws figures 1, 2a, 3a-b, and appendix figure a for Chetty (2011) 
% "Bounds on Elasticities with Optimization Frictions: A Synthesis of Micro
% and Macro Evidence on Labor Supply"

clear all

%0 Specify primitives

% Define taste parameter for figures 1-2: alpha=exp(a1/elast)
% Note: taste parameter for the other graphs are defined below
a1=3.5;

% Define annuitized wealth (Z/(T+1)) used for all figures
z=100;

% Define delta used for all figures
delta = 0.01;

% Define price change used in Figure 2 and initial price for Figure 1
% Note: price change for the other graphs are defined below
log_price_0=1;
log_price_1=1.2;

% Define elasticity used in Figures 1-2
% Note: elasticities for the other graphs are defined below
e1=1;

%Figure 1 Construction of Choice Set
% u(x)=Z-px+alpha*[x^(1-g)]/(1-g); q-linear util, no income effects
% use e=1, u(x)=Z-px+alpha*log(x) since [x^(1-g)]/(1-g)--> log(x) as e-->1

elast = e1;
alpha=exp(a1/elast);
price=exp(log_price_0);
g = 1/elast;

x_opt = (alpha/price)^elast;
width = x_opt*.615;
increment=.001*width;
x_vec = x_opt-width:increment:x_opt+1.7*width;
u_vec=z+(x_vec.*(-price))+log(x_vec).*alpha;
plot(x_vec,u_vec,'LineWidth',2.5,'Color',[0 0 1]);
x_opt_exp=x_opt^(1-g);
u_star = z+(-price*x_opt)+log(x_opt).*alpha;
u_range= u_star-delta*price*x_opt;
u_diff = abs(u_vec-u_range);
u_min=z+(-price*(x_opt-width))+log(x_opt-width).*alpha;
[minVal, minindex] = min(u_diff(x_vec<x_opt));
xmin_range = x_vec(minindex);
u_diff(x_vec<x_opt)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range = x_vec(minindex);

%Plot the utility function
v=axis;

line([x_opt+1.7*width x_opt-width], [u_range u_range],'LineWidth',1.2,'LineStyle','-','Color',[0 0 0])
line([xmin_range xmin_range], [u_min u_star*1.05],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
line([xmax_range xmax_range], [u_min u_star*1.05],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
ylabel('Utility U(x)')
xlabel('Demand (x)')
title('Choice Set in a delta Class of Models')
axis([4.8 22 139 151])

print -dmeta figure_1

x_range = xmax_range-xmin_range;

%Figure 2A Identification with Optimization Frictions
%Use code from figure 1 to compute ranges
%use elast e1
price_0=exp(log_price_0);
price_1=exp(log_price_1);

price=exp(0.4):0.01:exp(1.8);
x_opt=price.^-e1*(alpha^e1);
x_opt_p0 = (alpha/price_0)^e1;
width = x_opt_p0*.615;
increment=.001*width;
x_vec = (x_opt_p0-width):increment:(x_opt_p0+1.7*width);
u_vec=z+(x_vec.*(-price_0))+log(x_vec).*alpha;
u_star_p0 = z+(x_opt_p0*(-price_0))+log(x_opt_p0)*alpha;
u_range = u_star_p0-delta*price_0*x_opt_p0;
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p0));
xmin_range_p0 = x_vec(minindex);
u_diff(x_vec<x_opt_p0)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p0 = x_vec(minindex);

%replicate code for price_2
x_opt_p1 = (alpha/price_1)^e1;
x_vec = (x_opt_p1-width):increment:(x_opt_p1+1.7*width);
u_vec=z+(x_vec.*(-price_1))+log(x_vec).*alpha;
u_star_p1 = z+(x_opt_p1*(-price_1))+log(x_opt_p1)*alpha;
u_range = u_star_p1-(delta*price_1*x_opt_p1);
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p1));
xmin_range_p1 = x_vec(minindex);
u_diff(x_vec<x_opt_p1)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p1 = x_vec(minindex);

%Draw the plot
plot(log(price),log(x_opt),'LineWidth',2)
ylabel('Log Demand log(x)')
xlabel('Log Price log(p)')
title('Identification with Optimization Frictions e=1')
axis tight
v=axis;

%Hashed lines at p0 and p1
line([log(price_0) log(price_0)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
line([log(price_1) log(price_1)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])

%Red interval
line([log(price_0) log(price_0)], [log(xmin_range_p0) log(xmax_range_p0)],'LineWidth',2,'Color',[1 0 0])
line([log(price_1) log(price_1)], [log(xmin_range_p1) log(xmax_range_p1)],'LineWidth',2,'Color',[1 0 0])

print -dmeta figure_2a

%Figure 3A-B bounds
%Find maximum elasticity and minimum elasticity consistent with black line implied by an elasticity of 0.3 and delta = 1%. 

%Set new price interval
log_price_0=1;
log_price_1=1.4;

%Set e-hat at 0.3
price_change=exp(log_price_0):0.001:exp(log_price_1);
ehat=0.3;
alpha2=exp(3/ehat);
observed_treatment=price_change.^-ehat*(alpha2^ehat);

%Use Proposition 1 to find bounds
delta_log_price_squared=(log_price_1-log_price_0)^2;
rho=(1+0.5*ehat*(delta^-1)*delta_log_price_squared)^0.5;

%Compute Bounds
elast_lowerbound=ehat+((1-rho)*4*delta/delta_log_price_squared);
elast_upperbound=ehat+((1+rho)*4*delta/delta_log_price_squared);

%Figure 3A
%Highest elast that could have generated observed treatment effect
%Use code from figure 1 to compute ranges
price_0=exp(log_price_0);
price_1=exp(log_price_1);
elast = elast_upperbound;
a_max = 3.85;
alpha=exp(a_max/elast);

price=exp(-1):0.01:exp(2.5);
x_opt=price.^-elast*(alpha^elast);
x_opt_p0 = (alpha/price_0)^elast;
width = x_opt_p0*.615;
increment=.001*width;
x_vec = (x_opt_p0-width):increment:(x_opt_p0+1.7*width);
g=1/elast;

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_0))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p0 = z+(x_opt_p0*(-price_0))+((x_opt_p0^(1-g))*alpha/(1-g));
u_range = u_star_p0-delta*price_0*x_opt_p0;
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p0));
xmin_range_p0 = x_vec(minindex);
u_diff(x_vec<x_opt_p0)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p0 = x_vec(minindex);

%replicate code for price_2
x_opt_p1 = (alpha/price_1)^elast;
x_vec = (x_opt_p1-width):increment:(x_opt_p1+1.7*width);

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_1))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p1 = z+(x_opt_p1*(-price_1))+((x_opt_p1^(1-g))*alpha/(1-g));
u_range = u_star_p1-(delta*price_1*x_opt_p1);
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p1));
xmin_range_p1 = x_vec(minindex);
u_diff(x_vec<x_opt_p1)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p1 = x_vec(minindex);

%Define where y-axis should begin and end
y_min=a_max-(elast_upperbound*2.2);
y_max=a_max-(elast_upperbound*0.2);

%Draw the plot
plot(log(price),log(x_opt),'LineWidth',2)
axis([0.2 2.2 y_min y_max])
ylabel('Log Demand log(x)')
xlabel('Log Price log(p)')
title('Upper Bound on Structural Elasticity')
v=axis;

%Plot the observed treatment effect
line([log(price_change)], [log(observed_treatment)],'LineWidth',1,'Color',[0 0 0])

%Plot the hashed lines at p0 and p1
line([log(price_0) log(price_0)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
line([log(price_1) log(price_1)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])

%Plot the red interval
line([log(price_0) log(price_0)], [log(xmin_range_p0) log(xmax_range_p0)],'LineWidth',2,'Color',[1 0 0])
line([log(price_1) log(price_1)], [log(xmin_range_p1) log(xmax_range_p1)],'LineWidth',2,'Color',[1 0 0])

set(gca,'XTick',[0.2:0.2:2.2])
set(gca,'ytickmode','auto')

print -dmeta figure_3a

%Figure 3B:  Smallest elast that could have generated observed treatment effect
%Use code from figure 1 to compute ranges
price_0=exp(log_price_0);
price_1=exp(log_price_1);
elast = elast_lowerbound;
a_max = 2.736;
alpha=exp(a_max/elast);

price=exp(-1):0.01:exp(2.5);
x_opt=price.^-elast*(alpha^elast);
x_opt_p0 = (alpha/price_0)^elast;
width = x_opt_p0*.615;
increment=.001*width;
x_vec = (x_opt_p0-width):increment:(x_opt_p0+1.7*width);
g=1/elast;

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_0))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p0 = z+(x_opt_p0*(-price_0))+((x_opt_p0^(1-g))*alpha/(1-g));
u_range = u_star_p0-delta*price_0*x_opt_p0;
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p0));
xmin_range_p0 = x_vec(minindex);
u_diff(x_vec<x_opt_p0)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p0 = x_vec(minindex);

%replicate code for price_2
x_opt_p1 = (alpha/price_1)^elast;
x_vec = (x_opt_p1-width):increment:(x_opt_p1+1.7*width);

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_1))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p1 = z+(x_opt_p1*(-price_1))+((x_opt_p1^(1-g))*alpha/(1-g));
u_range = u_star_p1-(delta*price_1*x_opt_p1);
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p1));
xmin_range_p1 = x_vec(minindex);
u_diff(x_vec<x_opt_p1)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p1 = x_vec(minindex);

%Draw the plot
plot(log(price),log(x_opt),'LineWidth',2)
axis([0.2 2.2 y_min y_max])
ylabel('Log Demand log(x)')
xlabel('Log Price log(p)')
title('Lower Bound on Structural Elasticity')
v=axis;

%Plot the observed treatment effect
line([log(price_change)], [log(observed_treatment)],'LineWidth',1,'Color',[0 0 0])

%Plot the hashed lines at p0 and p1
line([log(price_0) log(price_0)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
line([log(price_1) log(price_1)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])

%Plot the red interval
line([log(price_0) log(price_0)], [log(xmin_range_p0) log(xmax_range_p0)],'LineWidth',2,'Color',[1 0 0])
line([log(price_1) log(price_1)], [log(xmin_range_p1) log(xmax_range_p1)],'LineWidth',2,'Color',[1 0 0])

set(gca,'XTick',[0.2:0.2:2.2])
set(gca,'ytickmode','auto')

print -dmeta figure_3b


%Appendix Figure A: Upper Bound on elast with Zero Observed Response
%Find maximum elasticity consistent with black line implied by an elasticity of 0 and delta = 1%. 

%Set prices
log_price_0=1;
log_price_1=1.4;

%Set e-hat at 0
price_change=exp(log_price_0):0.001:exp(log_price_1);
ehat=0;
alpha2=exp(3/ehat);
observed_treatment=price_change.^-ehat*(alpha2^ehat);
log_observed_treatment=3.11;


%Use Proposition 1 to find bounds
delta_log_price_squared=(log_price_1-log_price_0)^2;
rho=(1+0.5*ehat*(delta^-1)*delta_log_price_squared)^0.5;

%Compute Bounds
elast_lowerbound=ehat+((1-rho)*4*delta/delta_log_price_squared);
elast_upperbound=ehat+((1+rho)*4*delta/delta_log_price_squared);

%Highest elast that could have generated observed treatment effect
%Use code from figure 1 to compute ranges
price_0=exp(log_price_0);
price_1=exp(log_price_1);
elast = elast_upperbound;
a_max = 3.71;
alpha=exp(a_max/elast);

log_price = -1:0.01:2.5;
price=exp(-1):0.01:exp(2.5);
log_x1 = a1-(elast*log_price);
x_opt=price.^-elast*(alpha^elast);
x_opt_p0 = (alpha/price_0)^elast;
width = x_opt_p0*.615;
increment=.001*width;
x_vec = (x_opt_p0-width):increment:(x_opt_p0+1.7*width);
g=1/elast;

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_0))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p0 = z+(x_opt_p0*(-price_0))+((x_opt_p0^(1-g))*alpha/(1-g));
u_range = u_star_p0-delta*price_0*x_opt_p0;
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p0));
xmin_range_p0 = x_vec(minindex);
u_diff(x_vec<x_opt_p0)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p0 = x_vec(minindex);
x_range_p0=xmax_range_p0-xmin_range_p0;

%replicate code for price_2
x_opt_p1 = (alpha/price_1)^elast;
x_vec = (x_opt_p1-width):increment:(x_opt_p1+1.7*width);

%U(x)=Z-px+alpha*[x^(1-g)]/(1-g)
u_vec=z+(x_vec.*(-price_1))+(x_vec.^(1-g)*alpha/(1-g));
u_star_p1 = z+(x_opt_p1*(-price_1))+((x_opt_p1^(1-g))*alpha/(1-g));
u_range = u_star_p1-(delta*price_1*x_opt_p1);
u_diff = abs(u_vec-u_range);
[minVal, minindex] = min(u_diff(x_vec<x_opt_p1));
xmin_range_p1 = x_vec(minindex);
u_diff(x_vec<x_opt_p1)=Inf;
[minVal, minindex] = min(u_diff);
xmax_range_p1 = x_vec(minindex);
x_range_p1=xmax_range_p1-xmin_range_p1;

%Define where y-axis should begin and end
y_min=a_max-(elast_upperbound*2.2);
y_max=a_max-(elast_upperbound*0.2);

%Draw the plot
plot(log(price),log(x_opt),'LineWidth',2)
axis([0.2 2.2 y_min y_max])
ylabel('Log Demand log(x)')
xlabel('Log Price log(p)')
title('Upper Bound on e with Zero Observed Response')
v=axis;

%Plot the observed treatment effect
line([1 1.4], [log(xmin_range_p0) log(xmax_range_p1)],'LineWidth',1,'Color',[0 0 0])

%Plot the hashed lines at p0 and p1
line([log(price_0) log(price_0)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])
line([log(price_1) log(price_1)], [v(3) v(4)],'LineWidth',1,'LineStyle','--','Color',[0 0 0])

%Plot the red interval
line([log(price_0) log(price_0)], [log(xmin_range_p0) log(xmax_range_p0)],'LineWidth',2,'Color',[1 0 0])
line([log(price_1) log(price_1)], [log(xmin_range_p1) log(xmax_range_p1)],'LineWidth',2,'Color',[1 0 0])

set(gca,'XTick',[0.2:0.2:2.2])
set(gca,'YTick',[2.6:0.1:3.6])

print -dmeta figure_Aa