*---------------------------------------------------------------
* RESULTS FOR ALL YEARS: creates the all-years table
*---------------------------------------------------------------
/******************************************************************
"All Years" Results:

The code uses the taxcost-program: see this is you want details on how it works.

The "all years" results require the input of inflation data and the 
income levels which should be analyzed.  This data is contained in
median-cpi.dta, with the sources listed below.

The final products of the "all years" results are finaltimecost-extensive.dta
and finaltimecost-intensive.dta, which contain yearly data on the benefits
of optimizing for the extensive and intensive margin, expressed as a percentage of income.

Source of median income:
http://www.census.gov/hhes/www/income/histinc/f07ar.html
http://www.census.gov/hhes/www/income/histinc/h05.html
Source of CPI for all urban consumers:
http://data.bls.gov/cgi-bin/surveymost?blsf
Pay of accountants and tax preparers:
http://www.bls.gov/oco/ocos001.htm#earnings

Source of 99.5th percentile (Saez's website):
http://elsa.berkeley.edu/~saez/TabFig2006.xls

Source of lower income percentiles (from CPS data):
See "income percentiles.pdf" in the main directory
Similar data is available at: http://www.census.gov/hhes/www/income/histinc/h01ar.html

Last Updated: February 8th, 2011 by Jessica Laird, contact at jalpernl@gmail.com

******************************************************************/

clear
set mem 1000m
set more off

capture log close
log using table.log, replace

*PRE: Manipulate dataset before using taxcost

*Create a dataset with all the years and all the wages you want
use median-cpi, clear
drop if year==.
gen code=_n
gen ind=""

*Do some work to get all the different wage variables in one column: we need this to use taxcost

*First the "wagevars": save different dta-files to append later
local wagevars "allfamilies married wifepaid wifenotpaid singlemale singlefemale"
foreach wa of local wagevars{
	preserve
	keep code year ind `wa'
	ren `wa' pwages
	replace ind="`wa'"
	save wage-temp-`wa', replace
	restore
}

*Then for the percentiles; reshape instead
local percvars "pct ipct"
foreach pe of local percvars{
	preserve
	keep code year ind `pe'*
	reshape long `pe', i(code) j(lab 10 20 50 80 90 95 995)
	ren `pe' pwages
	replace ind="`pe'"+string(lab)
	drop lab
	save wage-temp-`pe', replace
	restore
}

use wage-temp-pct, clear
append using wage-temp-ipct
foreach wa of local wagevars{
	append using wage-temp-`wa'
	capture erase wage-temp-`wa'.dta
}

save graphs-temp, replace

capture erase wage-temp-pct.dta
capture erase wage-temp-ipct.dta

*Input proper information on tax payer characteristics
gen mstat = 3
gen state = 0
gen depx = 2
gen swages = 0
gen depchild = 2

*Fixing years: we want the postyear variable to be 3 years later
gen postyear=year+3

*Since taxsim only has data from 1960
drop if year<1960
drop if postyear>2009

*Since we don't have full pct-data before 1967
drop if year<1967

*Create "holes" for missing values
drop if pwages==.

*Only keep the necessary wages: change if you want to consider others!
keep if ind=="pct20" | ind=="pct50" | ind=="pct995"
replace ind="20" if ind=="pct20"
replace ind="50" if ind=="pct50"
replace ind="995" if ind=="pct995"

order year postyear code ind
sort year postyear code


*Specify e = elasticity of labor supply
gen e=.5

*Use taxcost; choose grid if you want something different than 1000: 10 is necessary to get the kinks right at low wages

taxcost1 10, replace_ext replace_int

local margin = "ext int"
foreach ma of local margin{
	preserve
	
	* Create some data on marginal tax rates
	gen diffMTRno = MTR_post_noopt - MTR_pre 
	gen diffNMTRno = -(MTR_post_noopt - MTR_pre)/(1-MTR_pre)*100
	lab var diffMTRno "MTR Change (Post - Pre), `linetype'ed Line"

	* Create variables on average tax rates
	gen diffATRno =  ATR_post_noopt - ATR_pre
	gen diffNATRno = abs((log(1-ATR_post_noopt) - log(1-ATR_pre))*100)
	lab var diffATRno "ATR Change (Post - Pre) for Non-Optimizers"

*--------------------------
*RESHAPE AND CREATE TABLE
*--------------------------
	
	keep postyear ind diffNMTRno diffNATRno percentgain_`ma'
	ren postyear year
	
	*Restrict the years you want to use
	drop if year<1970
	drop if year>2006
			
	ren percentgain_`ma' pc
	ren diffNMTRno mtr
	ren diffNATRno atr
	replace mtr = round(mtr,.01)
	replace atr = round(atr,.01)
	reshape wide pc atr mtr, i(year) j(ind) string
	order year pc* mtr* atr*
	saveold output_tables/finaltimecost-`ma', replace
	restore
}

log close

*End of code
